@@ -24,8 +24,8 @@ class MissionLightcurveBuilder(LightcurveBuilder):
         star_info = starinfo.StarInfo(sherlock_id, *self.star_catalogs[mission_prefix].catalog_info(id))
         logging.info("Downloading lightcurve files...")
         sectors = None if object_info.sectors == 'all' or mission != "TESS" else object_info.sectors
-        quarters = None if object_info.sectors == 'all' or mission != "K2" else object_info.sectors
-        campaigns = None if object_info.sectors == 'all' or mission != "Kepler" else object_info.sectors
+        campaigns = None if object_info.sectors == 'all' or mission != "K2" else object_info.sectors
+        quarters = None if object_info.sectors == 'all' or mission != "Kepler" else object_info.sectors
         if object_info.aperture_file is None:
             lcf_search_results = lk.search_lightcurve(str(mission_id), mission=mission, cadence=cadence,
                                            sector=sectors, quarter=quarters,
@@ -58,7 +58,8 @@ class MissionLightcurveBuilder(LightcurveBuilder):
                 logging.info("Correcting K2 motion in light curve...")
                 quarters = [lcfile.campaign for lcfile in lcf]
                 lc = lc.to_corrector("sff").correct(windows=20)
-            return lc, lc_data, star_info, transits_min_count, np.unique(sectors), np.unique(quarters)
+            return lc, lc_data, star_info, transits_min_count, None if sectors is None else np.unique(sectors), \
+                   None if quarters is None else np.unique(quarters)
         else:
             logging.info("Using user apertures!")
             tpf_search_results = lk.search_targetpixelfile(str(mission_id), mission=mission, cadence=cadence,
@@ -161,7 +162,8 @@ class MissionLightcurveBuilder(LightcurveBuilder):
                 logging.info("Correcting K2 motion in light curve...")
                 quarters = [lcfile.campaign for lcfile in tpfs]
             lc_data = None
-            return lc, lc_data, star_info, transits_min_count, np.unique(sectors), np.unique(quarters)
+            return lc, lc_data, star_info, transits_min_count, None if sectors is None else np.unique(sectors), \
+                   None if quarters is None else np.unique(quarters)
 
     def __calculate_transits_min_count(self, len_data):
         return 1 if len_data == 1 else 2
