@@ -26,5 +26,15 @@ class TicStarCatalog(StarCatalog):
         mass_min = result[0][73]
         if lum is None or np.isnan(lum):
             lum = self.star_luminosity(Teff, radius)
+        logg = result[0]["logg"] if "logg" in result[0].dtype.names else None
+        logg_err = result[0]["e_logg"] if "e_logg" in result[0].dtype.names else None
+        j = result[0]["Jmag"] if "Jmag" in result[0].dtype.names else None
+        j_err = result[0]["e_Jmag"] if "e_Jmag" in result[0].dtype.names else None
+        h = result[0]["Hmag"] if "Hmag" in result[0].dtype.names else None
+        h_err = result[0]["e_Hmag"] if "e_Hmag" in result[0].dtype.names else None
+        k = result[0]["Kmag"] if "Kmag" in result[0].dtype.names else None
+        k_err = result[0]["e_Kmag"] if "e_Kmag" in result[0].dtype.names else None
         ld, mass, mass_min, mass_max, radius, radius_min, radius_max = tls.catalog_info(TIC_ID=id)
-        return (ld, Teff, lum, logg, radius, radius_min, radius_max, mass, mass_min, mass_max, ra, dec)
+        return (ld, Teff, lum, logg, logg_err,
+                radius, radius_min, radius_max, mass, mass_min, mass_max, ra, dec, j, j_err,
+                h, h_err, k, k_err, None, None, None)
